<?php

namespace Modules\Cadastros\Services;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;

class Gql01200QualificacaoMarcasProdutoService
{
    protected $connection;
    
    public function __construct($entityManager, $environment)
    {
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
    }
    
    public function deleteQualificacaoMarcaProduto($row)
    {
        
		$param = array(
		    'P_CDMARCA'     => $row['CDMARCA'],
		    'P_CDPRODESTO'  => $row['CDPRODESTO'],
		    'P_CDPRODUTO'   => $row['CDPRODUTO'],
		    'P_MSG'         => $row['MSG']
		);
		
        $query = "DELETE 
                 FROM QFOMARPROD
                WHERE CDMARCA = :P_CDMARCA 
                  AND EXISTS (SELECT 1
                               FROM PRODUTO 
                              WHERE PRODUTO.CDPRODUTO = QFOMARPROD.CDPRODUTO 
                            AND ((PRODUTO.CDPRODESTO = :P_CDPRODESTO AND :P_MSG = 'S') 
                                    OR (PRODUTO.CDPRODUTO = :P_CDPRODUTO AND :P_MSG = 'N')))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function insertQualificacaoMarcaProduto($row)
    {
		$param = array(
		    'P_CDMARCA'     => $row['CDMARCA'],
		    'P_CDPRODUTO'   => $row['CDPRODUTO'],
		    'P_CDPRODESTO'  => $row['CDPRODESTO'],
		    'P_IDAPRMARPRO' => $row['IDAPRMARPRO'],
		    'P_IDAUTMARPRO' => $row['IDAUTMARPRO'],
		    'P_DTVALAPROVA' => $row['DTVALAPROVA'],
		    'P_MSG'         => $row['MSG']
		);
		
        $query = "INSERT INTO QFOMARPROD (
                    CDPRODUTO,
                    CDMARCA,
                    IDAPRMARPRO,
                    IDAUTMARPRO,
                    DTVALAPROVA
                )
                    SELECT
                        PRODUTO.CDPRODUTO,
                        :P_CDMARCA,
                        :P_IDAPRMARPRO,
                        :P_IDAUTMARPRO,
                        :P_DTVALAPROVA
                    FROM
                        PRODUTO
                    WHERE
                        ( ( PRODUTO.CDPRODESTO = :P_CDPRODESTO
                            AND :P_MSG = 'S' )
                          OR ( PRODUTO.CDPRODUTO = :P_CDPRODUTO
                               AND :P_MSG = 'N' ) )
                        AND NOT EXISTS (
                            SELECT
                                CDPRODUTO
                            FROM
                                QFOMARPROD Q
                            WHERE
                                Q.CDPRODUTO = PRODUTO.CDPRODUTO
                                AND Q.CDMARCA   = :P_CDMARCA
                        )";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function updateQualificacao($row)
    {
		$param = array(
		    'P_CDMARCA'     => $row['CDMARCA'],
		    'P_CDPRODESTO'  => $row['CDPRODESTO'],
		    'P_IDAPRMARPRO' => $row['IDAPRMARPRO'],
		    'P_IDAUTMARPRO' => $row['IDAUTMARPRO'],
		    'P_DTVALAPROVA' => $row['DTVALAPROVA']
		);
		
        $query = "UPDATE QFOMARPROD
                SET
                  IDAPRMARPRO = :P_IDAPRMARPRO,
                  IDAUTMARPRO = :P_IDAUTMARPRO,
                  DTVALAPROVA = :P_DTVALAPROVA
                WHERE
                   CDMARCA = :P_CDMARCA 
                   AND EXISTS (SELECT 1
        		               FROM PRODUTO
                                    WHERE PRODUTO.CDPRODUTO = QFOMARPROD.CDPRODUTO 
                                        AND PRODUTO.CDPRODESTO = :P_CDPRODESTO)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function insertMarcaProduto($row)
    {
		$param = array(
		    'P_CDMARCA'     => $row['CDMARCA'],
		    'P_CDPRODUTO'   => $row['CDPRODUTO'],
		    'P_CDPRODESTO'  => $row['CDPRODESTO'],
		    'P_MSG'         => $row['MSG']
		);
		
        $query = "INSERT INTO MARCPROD (
                    CDPRODUTO,
                    CDMARCA
                )
                    ( SELECT
                        CDPRODUTO,
                        :P_CDMARCA
                    FROM
                        PRODUTO
                    WHERE
                        ( ( PRODUTO.CDPRODESTO = :P_CDPRODESTO
                            AND :P_MSG = 'S' )
                          OR ( PRODUTO.CDPRODUTO = :P_CDPRODUTO
                               AND :P_MSG = 'N' ) )
                        AND NOT EXISTS (
                            SELECT
                                CDMARCA
                            FROM
                                MARCPROD,
                                PRODUTO P
                            WHERE
                                P.CDPRODUTO = MARCPROD.CDPRODUTO
                                AND CDMARCA = :P_CDMARCA
                                AND PRODUTO.CDARVPROD LIKE P.CDARVPROD || '%'
                        )
                    )";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function procInsertQualificacaoMarcaProduto($row)
    {
        $connection = $this->connection;
        $procedure = new StoredProcedure($connection, 'INSERE_PRODFORNCMP_MARCFORNCMP');
        $procedure->addParam(new Param('P_CDFORNECED',  Param::PARAM_INPUT, null,               Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDMARCA',     Param::PARAM_INPUT, $row['CDMARCA'],    Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODUTO',   Param::PARAM_INPUT, $row['CDPRODUTO'],  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDARVPROD',   Param::PARAM_INPUT, $row['CDARVPROD'],  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_ARRED',       Param::PARAM_INPUT, null,               Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFORNORIG',  Param::PARAM_INPUT, null,               Param::PARAM_TYPE_STR));
        $rowsaffect = $procedure->execute();
    }
    
    public function getMarca($row){
		$param = array(
		    'P_CDPRODUTO'   => $row['CDPRODUTO'],
		    'P_CDMARCA'     => $row['CDMARCA'],
		);
		
        $query = "SELECT
                     CDMARCA
                 FROM
                     QFOMARPROD
                 WHERE
                     ( CDPRODUTO =:P_CDPRODUTO )
                     AND ( CDMARCA =:P_CDMARCA )";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            
            return $std->fetchAll();
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function updateQualificacaoMarcaProduto($row)
    {
		$param = array(
		    'P_CDMARCA'     => $row['CDMARCA'],
		    'P_CDPRODESTO'  => $row['CDPRODESTO'],
		    'P_CDPRODUTO'   => $row['CDPRODUTO'],
		    'P_MSG'         => $row['MSG'],
		    'P_IDAPRMARPRO' => $row['IDAPRMARPRO'],
		    'P_IDAUTMARPRO' => $row['IDAUTMARPRO'],
		    'P_DTVALAPROVA' => $row['DTVALAPROVA'],
		    
		);
		
        $query = "UPDATE QFOMARPROD
                SET
                  IDAPRMARPRO = :P_IDAPRMARPRO,
                  IDAUTMARPRO = :P_IDAUTMARPRO,
                  DTVALAPROVA = :P_DTVALAPROVA
                WHERE CDMARCA = :P_CDMARCA 
                  AND EXISTS (SELECT 1
                               FROM PRODUTO 
                              WHERE PRODUTO.CDPRODUTO = QFOMARPROD.CDPRODUTO 
                                AND ((PRODUTO.CDPRODESTO = :P_CDPRODESTO AND :P_MSG = 'S') 
                                    OR (PRODUTO.CDPRODUTO = :P_CDPRODUTO AND :P_MSG = 'N')))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function selectOperador($row)
    {
        $params = array(
            'P_CDOPERADOR' => $row['CDOPERADOR']
                
        );
        
        $query = "SELECT
                    CDOPERADOR,
                    NMOPERADOR,
                    CDSENHOPER
                FROM
                    OPERADOR
                WHERE
                    CDOPERADOR = :P_CDOPERADOR";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }
}